@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from design.plone.contenttypes.utils import create_default_blocks
 from Products.CMFPlone.interfaces import ISelectableConstrainTypes
 from plone import api
 
@@ -17,14 +18,16 @@ def notiziaCreateHandler(notizia, event):
         multimedia = api.content.create(
             type="Document", title="Multimedia", container=notizia
         )
+        create_default_blocks(context=multimedia)
         constraintsMultimedia = ISelectableConstrainTypes(multimedia)
         constraintsMultimedia.setConstrainTypesMode(1)
         constraintsMultimedia.setLocallyAllowedTypes(("Link", "Image"))
 
     if "documenti-allegati" not in notizia.keys():
-        multimedia = api.content.create(
+        documenti = api.content.create(
             type="Document", title="Documenti allegati", container=notizia
         )
-        constraintsMultimedia = ISelectableConstrainTypes(multimedia)
-        constraintsMultimedia.setConstrainTypesMode(1)
-        constraintsMultimedia.setLocallyAllowedTypes(("File", "Image"))
+        create_default_blocks(context=documenti)
+        constraintsDocumenti = ISelectableConstrainTypes(documenti)
+        constraintsDocumenti.setConstrainTypesMode(1)
+        constraintsDocumenti.setLocallyAllowedTypes(("File", "Image"))
