@@ -7,8 +7,7 @@ from zope import schema
 
 
 class IDataset(model.Schema):
-    """ Marker interface for Dataset
-    """
+    """Marker interface for Dataset"""
 
     # TODO: aggiungere tassonomia e vocabolario rilevante fornito nelle linee guida  # noqa
     temi = schema.Choice(
@@ -23,21 +22,15 @@ class IDataset(model.Schema):
         title=_(u"distribuzione", default=u"Distribuzione"), required=True
     )
 
-    licenza = schema.TextLine(
-        title=_(u"licenza", default=u"Licenza"), required=True
-    )
+    licenza = schema.TextLine(title=_(u"licenza", default=u"Licenza"), required=True)
 
     dataset = field.NamedBlobFile(
         title=_(u"dataset", default=u"Dataset"), required=True
     )
 
-    titolare = schema.TextLine(
-        title=_(u"titolare", default=u"Titolare"), required=True
-    )
+    titolare = schema.TextLine(title=_(u"titolare", default=u"Titolare"), required=True)
 
     frequenza_aggiornamento = schema.TextLine(
-        title=_(
-            u"frequenza_aggiornamento", default=u"Frequenza di aggiornamento"
-        ),
+        title=_(u"frequenza_aggiornamento", default=u"Frequenza di aggiornamento"),
         required=True,
     )
