@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
-from design.plone.contenttypes import _
 from collective.volto.blocksfield.field import BlocksField
+from design.plone.contenttypes import _
+from design.plone.contenttypes.interfaces import IDesignPloneContentType
 from plone.app.z3cform.widget import RelatedItemsFieldWidget
 from plone.autoform import directives as form
 from plone.supermodel import model
@@ -9,7 +10,7 @@ from z3c.relationfield.schema import RelationList
 from zope import schema
 
 
-class IDocumento(model.Schema):
+class IDocumento(model.Schema, IDesignPloneContentType):
     """Marker interface for content type Documento"""
 
     identificativo = schema.TextLine(
@@ -25,9 +26,7 @@ class IDocumento(model.Schema):
     )
 
     tipologia_documento = schema.Choice(
-        title=_(
-            "tipologia_documento_label", default="Tipologia del documento"
-        ),
+        title=_("tipologia_documento_label", default="Tipologia del documento"),
         description=_(
             "tipologia_documento_help",
             default="Seleziona la tipologia del documento.",
@@ -38,14 +37,14 @@ class IDocumento(model.Schema):
 
     ufficio_responsabile = RelationList(
         title=_(
-            "ufficio_responsabile_label",
+            "ufficio_responsabile_documento_label",
             default="Ufficio responsabile del documento",
         ),
         description=_(
-            "ufficio_responsabile_help",
+            "ufficio_responsabile_documento_help",
             default="Seleziona l'ufficio responsabile di questo documento.",
         ),
-        required=True,
+        required=False,
         default=[],
         value_type=RelationChoice(
             title=_(u"Ufficio responsabile"),
@@ -60,10 +59,9 @@ class IDocumento(model.Schema):
         ),
         description=_(
             "area_responsabile_help",
-            default="Seleziona l'area amministrativa responsabile del "
-            "documento.",
+            default="Seleziona l'area amministrativa responsabile del " "documento.",
         ),
-        required=True,
+        required=False,
         default=[],
         value_type=RelationChoice(
             title=_(u"Area"), vocabulary="plone.app.vocabularies.Catalog"
@@ -71,7 +69,10 @@ class IDocumento(model.Schema):
     )
 
     autori = RelationList(
-        title=_("autori_label", default="Autore/i",),
+        title=_(
+            "autori_label",
+            default="Autore/i",
+        ),
         description=_(
             "autori_help",
             default="Seleziona una lista di autori che hanno pubblicato "
@@ -83,9 +84,7 @@ class IDocumento(model.Schema):
     )
 
     licenza_distribuzione = schema.TextLine(
-        title=_(
-            "licenza_distribuzione_label", default="Licenza di distribuzione"
-        ),
+        title=_("licenza_distribuzione_label", default="Licenza di distribuzione"),
         description=_(
             "licenza_distribuzione_help",
             default="La licenza con il quale viene distribuito questo documento.",
@@ -93,26 +92,13 @@ class IDocumento(model.Schema):
         required=False,
     )
 
-    servizi_collegati = RelationList(
-        title=_("servizi_collegati_label", default="Servizi collegati"),
-        description=_(
-            "servizi_collegati_help",
-            default="Seleziona una lista di servizi collegati a questo "
-            "documento.",
-        ),
-        default=[],
-        value_type=RelationChoice(
-            vocabulary="plone.app.vocabularies.Catalog",
-        ),
-        required=False,
-    )
-
     riferimenti_normativi = BlocksField(
         title=_(
-            "riferimenti_normativi_label", default="Riferimenti normativi"
+            "riferimenti_normativi_documento_label",
+            default="Riferimenti normativi",
         ),
         description=_(
-            "riferimenti_normativi_help",
+            "riferimenti_normativi_documento_help",
             default="Inserisici del testo di dettaglio per eventuali "
             "riferimenti normativi utili a questo documento.",
         ),
@@ -120,7 +106,10 @@ class IDocumento(model.Schema):
     )
 
     documenti_allegati = RelationList(
-        title=_("documenti_allegati_label", default="Documenti allegati",),
+        title=_(
+            "documenti_allegati_label",
+            default="Documenti allegati",
+        ),
         description=_(
             "documenti_allegati_help",
             default="Seleziona una serie di altri contenuti di tipo Documento "
@@ -151,15 +140,6 @@ class IDocumento(model.Schema):
             "selectableTypes": ["Persona", "UnitaOrganizzativa"],
         },
     )
-    form.widget(
-        "servizi_collegati",
-        RelatedItemsFieldWidget,
-        vocabulary="plone.app.vocabularies.Catalog",
-        pattern_options={
-            "maximumSelectionSize": 10,
-            "selectableTypes": ["Servizio"],
-        },
-    )
     form.widget(
         "area_responsabile",
         RelatedItemsFieldWidget,
@@ -173,10 +153,7 @@ class IDocumento(model.Schema):
         "documenti_allegati",
         RelatedItemsFieldWidget,
         vocabulary="plone.app.vocabularies.Catalog",
-        pattern_options={
-            "maximumSelectionSize": 10,
-            "selectableTypes": ["Documento"],
-        },
+        pattern_options={"maximumSelectionSize": 10, "selectableTypes": ["Documento"]},
     )
 
     #  custom fieldsets
@@ -191,11 +168,6 @@ class IDocumento(model.Schema):
         ],
     )
 
-    model.fieldset(
-        "accedere_al_servizio",
-        label=_("accedere_al_servizio_label", default="Accedere al servizio"),
-        fields=["servizi_collegati"],
-    )
     model.fieldset(
         "informazioni",
         label=_("informazioni_label", default=u"Ulteriori informazioni"),
