@@ -7,11 +7,7 @@ import logging
 
 logger = logging.getLogger("design.plone.contenttypes.patches")
 
-logger.info(
-    "Patching plone.restapi.serializer.dxcontent.SerializeToJson._call__"
-)
-logger.info(
-    "Patching plone.restapi.serializer.dxcontent.SerializeFolderToJson._call__"
-)
+logger.info("Patching plone.restapi.serializer.dxcontent.SerializeToJson._call__")
+logger.info("Patching plone.restapi.serializer.dxcontent.SerializeFolderToJson._call__")
 patch_base_serializer()
 patch_base_folder_serializer()
