@@ -7,14 +7,12 @@ import plone.protect.interfaces
 
 
 class CorrelatiService(Service):
-    """ Service to make action """
+    """Service to make action"""
 
     def reply(self):
         # Disable CSRF protection
         if "IDisableCSRFProtection" in dir(plone.protect.interfaces):
-            alsoProvides(
-                self.request, plone.protect.interfaces.IDisableCSRFProtection
-            )
+            alsoProvides(self.request, plone.protect.interfaces.IDisableCSRFProtection)
 
         results = api.content.get_view(
             name="correlati",
