@@ -11,18 +11,15 @@ from design.plone.contenttypes.interfaces.bando import IBandoAgidSchema
 @adapter(IBandoAgidSchema, Interface)
 class BandoSerializer(BaseSerializer):
     def get_approfondimenti(self, bando_view):
-        """
-        """
+        """ """
         folders = bando_view.retrieveFolderDeepening()
         results = []
 
         for folder in folders:
-            contents = bando_view.retrieveContentsOfFolderDeepening(
-                folder["path"]
-            )
+            contents = bando_view.retrieveContentsOfFolderDeepening(folder["path"])
             folder.update({"children": contents})
             results.append(folder)
-        return sorted(results, key=lambda k: k["title"])
+        return results
 
     def __call__(self, version=None, include_items=True):
         result = super(BandoSerializer, self).__call__(
