@@ -67,9 +67,7 @@ class VenueSerializer(RelatedNewsSerializer):
 
     def __call__(self, version=None, include_items=True):
         self.index = "news_venue"
-        result = super(VenueSerializer, self).__call__(
-            version=None, include_items=True
-        )
+        result = super(VenueSerializer, self).__call__(version=None, include_items=True)
         result["venue_services"] = self.get_venue_services(result)
         result["sede_di"] = self.get_venue_offices(result)
         return result
