@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from plone import api
+from redturtle.bandi.interfaces.settings import IBandoSettings
 from Products.CMFPlone.interfaces import INonInstallable
 from zope.interface import implementer
 
@@ -22,6 +23,18 @@ def post_install(context):
             [x for x in portal_types[ptype].behaviors if x != "volto.blocks"]
         )
 
+    # add image fields at the end of document behaviors
+    document_behaviors = [
+        x
+        for x in portal_types["Document"].behaviors
+        if x not in ["plone.leadimage", "volto.preview_image"]
+    ]
+    document_behaviors.extend(["plone.leadimage", "volto.preview_image"])
+    portal_types["Document"].behaviors = tuple(document_behaviors)
+
+    # remove default ente
+    api.portal.set_registry_record("default_ente", (), interface=IBandoSettings)
+
 
 def uninstall(context):
     """Uninstall script"""
