@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
-from plone.app.contenttypes.testing import PLONE_APP_CONTENTTYPES_FIXTURE
 from plone.app.testing import applyProfile
 from plone.app.testing import FunctionalTesting
 from plone.app.testing import IntegrationTesting
-from plone.app.testing import PloneSandboxLayer
-from plone.restapi.testing import PloneRestApiDXLayer
 from plone.testing import z2
+from zope.configuration import xmlconfig
+from redturtle.volto.testing import RedturtleVoltoLayer
+from redturtle.volto.testing import RedturtleVoltoRestApiLayer
+
 
 import collective.address
 import collective.dexteritytextindexer
@@ -14,35 +15,25 @@ import collective.venue
 import collective.volto.blocksfield
 import collective.volto.cookieconsent
 import design.plone.contenttypes
+import kitconcept.seo
 import plone.app.caching
 import plone.formwidget.geolocation
 import plone.restapi
 import redturtle.bandi
 import redturtle.volto
 
-from zope.configuration import xmlconfig
-
-
-class DesignPloneContenttypesLayer(PloneSandboxLayer):
-
-    defaultBases = (PLONE_APP_CONTENTTYPES_FIXTURE,)
 
+class DesignPloneContenttypesLayer(RedturtleVoltoLayer):
     def setUpZope(self, app, configurationContext):
         # Load any other ZCML that is required for your tests.
         # The z3c.autoinclude feature is disabled in the Plone fixture base
         # layer.
+        super().setUpZope(app, configurationContext)
         self.loadZCML(package=collective.dexteritytextindexer)
-        self.loadZCML(package=collective.folderishtypes)
         self.loadZCML(package=collective.venue)
         self.loadZCML(package=collective.volto.blocksfield)
-        self.loadZCML(package=collective.volto.cookieconsent)
-        self.loadZCML(
-            package=design.plone.contenttypes, context=configurationContext
-        )
-        self.loadZCML(package=plone.app.caching)
+        self.loadZCML(package=design.plone.contenttypes, context=configurationContext)
         self.loadZCML(package=plone.formwidget.geolocation)
-        self.loadZCML(package=plone.restapi)
-        self.loadZCML(package=redturtle.volto)
         self.loadZCML(name="overrides.zcml", package=design.plone.contenttypes)
         xmlconfig.file(
             "configure.zcml",
@@ -50,9 +41,10 @@ class DesignPloneContenttypesLayer(PloneSandboxLayer):
             context=configurationContext,
         )
         self.loadZCML(package=redturtle.bandi)
+        self.loadZCML(package=kitconcept.seo)
 
     def setUpPloneSite(self, portal):
-        applyProfile(portal, "plone.app.caching:default")
+        super().setUpPloneSite(portal)
         applyProfile(portal, "design.plone.contenttypes:default")
 
 
@@ -71,30 +63,25 @@ DESIGN_PLONE_CONTENTTYPES_FUNCTIONAL_TESTING = FunctionalTesting(
 )
 
 
-class DesignPloneContenttypesRestApiLayer(PloneRestApiDXLayer):
-
-    defaultBases = (PLONE_APP_CONTENTTYPES_FIXTURE,)
-
+class DesignPloneContenttypesRestApiLayer(RedturtleVoltoRestApiLayer):
     def setUpZope(self, app, configurationContext):
-        super(DesignPloneContenttypesRestApiLayer, self).setUpZope(
-            app, configurationContext
-        )
-
+        super().setUpZope(app, configurationContext)
         self.loadZCML(package=collective.dexteritytextindexer)
-        self.loadZCML(package=collective.folderishtypes)
         self.loadZCML(package=collective.venue)
         self.loadZCML(package=collective.volto.blocksfield)
-        self.loadZCML(package=collective.volto.cookieconsent)
-        self.loadZCML(package=design.plone.contenttypes)
-        self.loadZCML(name="overrides.zcml", package=design.plone.contenttypes)
-        self.loadZCML(package=plone.app.caching)
+        self.loadZCML(package=design.plone.contenttypes, context=configurationContext)
         self.loadZCML(package=plone.formwidget.geolocation)
-        self.loadZCML(package=plone.restapi)
-        self.loadZCML(package=redturtle.volto)
+        self.loadZCML(name="overrides.zcml", package=design.plone.contenttypes)
+        xmlconfig.file(
+            "configure.zcml",
+            design.plone.contenttypes,
+            context=configurationContext,
+        )
         self.loadZCML(package=redturtle.bandi)
+        self.loadZCML(package=kitconcept.seo)
 
     def setUpPloneSite(self, portal):
-        applyProfile(portal, "plone.app.caching:default")
+        super().setUpPloneSite(portal)
         applyProfile(portal, "design.plone.contenttypes:default")
 
 
