@@ -4,10 +4,11 @@ from design.plone.contenttypes.testing import (
     DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING,
 )
 from plone import api
+
 import unittest
 
 
-class TestDocument(unittest.TestCase):
+class TestCartellaModulistica(unittest.TestCase):
     layer = DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING
 
     def setUp(self):
@@ -27,15 +28,18 @@ class TestDocument(unittest.TestCase):
                 "plone.publication",
                 "plone.categorization",
                 "plone.basic",
+                "plone.leadimage",
+                "volto.preview_image",
                 "plone.locking",
                 "volto.blocks",
                 "plone.translatable",
+                "kitconcept.seo",
             ),
         )
 
     def test_event_addable_types(self):
         portal_types = api.portal.get_tool(name="portal_types")
         self.assertEqual(
-            ("Document", "Documento", "Link", "Image"),
+            ("Document", "Documento", "Link", "Image", "File"),
             portal_types["CartellaModulistica"].allowed_content_types,
         )
