@@ -25,12 +25,17 @@ class TestDocument(unittest.TestCase):
                 "plone.shortname",
                 "plone.dublincore",
                 "plone.relateditems",
+                "plone.locking",
+                "volto.blocks",
                 "plone.versioning",
                 "plone.tableofcontents",
-                "plone.locking",
-                "plone.constraintypes",
-                "volto.blocks",
                 "design.plone.contenttypes.behavior.info_testata",
+                "design.plone.contenttypes.behavior.argomenti_document",
                 "plone.translatable",
+                "design.plone.contenttypes.behavior.show_modified",
+                "kitconcept.seo",
+                "plone.constraintypes",
+                "plone.leadimage",
+                "volto.preview_image",
             ),
         )
