@@ -30,6 +30,7 @@ class TestEvent(unittest.TestCase):
             (
                 "plone.eventbasic",
                 "plone.leadimage",
+                "volto.preview_image",
                 "design.plone.contenttypes.behavior.argomenti",
                 "plone.eventrecurrence",
                 "design.plone.contenttypes.behavior.additional_help_infos",
@@ -49,6 +50,7 @@ class TestEvent(unittest.TestCase):
                 "plone.constraintypes",
                 "collective.dexteritytextindexer",
                 "plone.translatable",
+                "kitconcept.seo",
             ),
         )
 
@@ -76,9 +78,7 @@ class TestEventApi(unittest.TestCase):
         self.event = api.content.create(
             container=self.portal, type="Event", title="Evento"
         )
-        provideAdapter(
-            SchemaTweaks, (IFormFieldProvider,), name="schema.tweaks"
-        )
+        provideAdapter(SchemaTweaks, (IFormFieldProvider,), name="schema.tweaks")
         transaction.commit()
 
     def tearDown(self):
@@ -94,15 +94,11 @@ class TestEventApi(unittest.TestCase):
 
         self.assertEqual(event["multimedia"].portal_type, "Document")
         self.assertEqual(event["multimedia"].constrain_types_mode, 1)
-        self.assertEqual(
-            event["multimedia"].locally_allowed_types, ("Image", "Link")
-        )
+        self.assertEqual(event["multimedia"].locally_allowed_types, ("Image", "Link"))
 
         self.assertEqual(event["sponsor_evento"].portal_type, "Document")
         self.assertEqual(event["sponsor_evento"].constrain_types_mode, 1)
-        self.assertEqual(
-            event["sponsor_evento"].locally_allowed_types, ("Link",)
-        )
+        self.assertEqual(event["sponsor_evento"].locally_allowed_types, ("Link",))
 
         self.assertEqual(event["documenti"].portal_type, "Document")
         self.assertEqual(event["documenti"].constrain_types_mode, 1)
