@@ -37,6 +37,7 @@ class TestLuogo(unittest.TestCase):
                 "plone.app.dexterity.behaviors.metadata.ICategorization",
                 "plone.relateditems",
                 "plone.leadimage",
+                "volto.preview_image",
                 "design.plone.contenttypes.behavior.contatti_venue",
                 "design.plone.contenttypes.behavior.luogo",
                 "design.plone.contenttypes.behavior.argomenti",
@@ -45,6 +46,7 @@ class TestLuogo(unittest.TestCase):
                 "design.plone.contenttypes.behavior.additional_help_infos",
                 "collective.dexteritytextindexer",
                 "plone.translatable",
+                "kitconcept.seo",
             ),
         )
 
@@ -87,14 +89,19 @@ class TestLuogoApi(unittest.TestCase):
         self.service.dove_rivolgersi = [venue]
         self.uo.luoghi_correlati = [venue]
         pcatalog = getToolByName(self.portal, "portal_catalog")
-        pcatalog.manage_reindexIndex(
-            ids=["service_venue", "office_venue", "news_venue"]
-        )
+        pcatalog.manage_reindexIndex(ids=["service_venue", "uo_location", "news_venue"])
         commit()
 
     def tearDown(self):
         self.api_session.close()
 
+    def test_venus_addable_types(self):
+        portal_types = api.portal.get_tool(name="portal_types")
+        self.assertEqual(
+            ("Folder", "Link", "Image", "File"),
+            portal_types["Venue"].allowed_content_types,
+        )
+
     def test_venue_geolocation_deserializer_wrong_structure(self):
         venue = api.content.create(
             container=self.portal, type="Venue", title="Example venue"
@@ -105,11 +112,7 @@ class TestLuogoApi(unittest.TestCase):
 
         response = self.api_session.patch(
             venue.absolute_url(),
-            json={
-                "@type": "Venue",
-                "title": "Foo",
-                "geolocation": {"foo": "bar"},
-            },
+            json={"@type": "Venue", "title": "Foo", "geolocation": {"foo": "bar"}},
         )
         message = response.json()["message"]
 
@@ -140,18 +143,14 @@ class TestLuogoApi(unittest.TestCase):
         self.assertEqual(venue.geolocation.longitude, 10.0)
 
     def test_venue_services(self):
-        response = self.api_session.get(
-            self.venue.absolute_url() + "?fullobjects"
-        )
+        response = self.api_session.get(self.venue.absolute_url() + "?fullobjects")
         self.assertTrue(
             response.json()["venue_services"][0]["@id"],
             self.service.absolute_url(),
         )
 
     def test_venue_news(self):
-        response = self.api_session.get(
-            self.venue.absolute_url() + "?fullobjects"
-        )
+        response = self.api_session.get(self.venue.absolute_url() + "?fullobjects")
 
         self.assertTrue(
             response.json()["related_news"][0]["@id"], self.news.absolute_url()
